//
// Open Service Platform
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file	FIo_ChannelServiceStub.h
 * @brief	This is the header file for the _ChannelServiceStub class.
 *
 * This file contains the declarations of _ChannelServiceStub.
 */


#ifndef _FIO_INTERNAL_CHANNEL_SERVICE_STUB_H_
#define _FIO_INTERNAL_CHANNEL_SERVICE_STUB_H_

#include <FOspConfig.h>
#include <FBaseResult.h>
#include <FBaseObject.h>
#include <FBaseColArrayList.h>
#include <FBaseRt_ITask.h>
#include "FIo_IIpcServerEventListener.h"
#include "FIo_IChannelServiceStub.h"

namespace IPC
{
class Message;
}

namespace Tizen { namespace Io
{

class _IpcServer;
class _ChannelService;

class _OSP_EXPORT_ _ChannelServiceStub
	: public _IIpcServerEventListener
	, public _IChannelServiceStub
	, public Tizen::Base::Object
{
public:
	_ChannelServiceStub(void);

	virtual ~_ChannelServiceStub(void);

	virtual result Construct(void);

	// _IChannelServiceStub
	virtual result SendRequest(int clientId, const Tizen::Base::String& src,
							   const Tizen::Base::String& dest,
							   const Tizen::Base::Collection::ArrayList& args,
							   int requestId);

	virtual result SendNullRequest(int clientId, const Tizen::Base::String& src,
							   const Tizen::Base::String& dest,
							   int requestId);

	virtual result SendResponse(int clientId, const Tizen::Base::String& src,
								const Tizen::Base::String& dest,
								const Tizen::Base::Collection::ArrayList& args,
								int requestId);

	virtual result SendNullResponse(int clientId, const Tizen::Base::String& src,
								const Tizen::Base::String& dest,
								int requestId);

	virtual void SetChannelService(_ChannelService& service);


private:
	bool OnRegisterChannelMessage(const Tizen::Base::String& appId, int* pResult);

	bool OnSendRequestMessage(const Tizen::Base::String& src,
							  const Tizen::Base::String& dest,
							  const Tizen::Base::Collection::ArrayList& args,
							  int requestId,
							  int* pResult);

	bool OnSendNullRequestMessage(const Tizen::Base::String& src,
							  const Tizen::Base::String& dest,
							  int requestId,
							  int* pResult);

	bool OnSendResponseMessage(const Tizen::Base::String& src,
							   const Tizen::Base::String& dest,
							   const Tizen::Base::Collection::ArrayList& args,
							   int requestId,
							   int* pResult);

	bool OnSendNullResponseMessage(const Tizen::Base::String& src,
							   const Tizen::Base::String& dest,
							   int requestId,
							   int* pResult);

	virtual void OnIpcRequestReceived(_IpcServer& server, const IPC::Message& message);

	virtual void OnIpcServerStarted(const _IpcServer& server);

	virtual void OnIpcServerStopped(const _IpcServer& server);

	virtual void OnIpcClientConnected(const _IpcServer& server, int clientId);

	virtual void OnIpcClientDisconnected(const _IpcServer& server, int clientId);

	_ChannelServiceStub(const _ChannelServiceStub& value);
	_ChannelServiceStub& operator = (const _ChannelServiceStub& value);
private:
	_IpcServer* __pIpcServer;
	_ChannelService* __pChannelService;

}; // _ChannelServiceStub

} } // Tizen::Io

#endif // _FIO_INTERNAL_CHANNEL_SERVICE_STUB_H_

