//
// Open Service Platform
// Copyright (c) 2012 Samsung Electronics Co., Ltd.
//
// Licensed under the Apache License, Version 2.0 (the License);
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

/**
 * @file	FIo_MessagePortStub.h
 * @brief	This is the header file for the _MessagePortStub class.
 *
 * This file contains the declarations of _MessagePortStub.
 */


#ifndef _FIO_INTERNAL_MESSAGE_PORT_STUB_H_
#define _FIO_INTERNAL_MESSAGE_PORT_STUB_H_

#include <message-port-data-types.h>

#include <FBaseResult.h>
#include <FBaseObject.h>
#include <FBaseColArrayList.h>
#include <FBaseColHashMap.h>
#include <FAppTypes.h>

#include "IpcServer.h"
#include "IIpcServerEventListener.h"

namespace IPC
{
class Message;
}

class _MessagePortService;

class _MessagePortStub
	: public IIpcServerEventListener
{
public:
	_MessagePortStub(void);
	virtual ~_MessagePortStub(void);

	virtual result Construct(void);

	result SendMessage(int clientId, const BundleBuffer& metadata, const BundleBuffer& buffer);

	void SetMessagePortService(_MessagePortService& service);

private:
	bool OnRegisterMessagePort(const BundleBuffer& buffer, int* pResult);

	bool OnCheckRemotePort(const BundleBuffer& buffer, int* pResult);

	bool OnSendMessage(const BundleBuffer& metadata, const BundleBuffer& buffer, int* pResult);

	virtual void OnIpcRequestReceived(IpcServer& server, const IPC::Message& message);

	virtual void OnIpcServerStarted(const IpcServer& server);

	virtual void OnIpcServerStopped(const IpcServer& server);

	virtual void OnIpcClientConnected(const IpcServer& server, int clientId);

	virtual void OnIpcClientDisconnected(const IpcServer& server, int clientId);

	_MessagePortStub(const _MessagePortStub& value);
	_MessagePortStub& operator = (const _MessagePortStub& value);

private:
	IpcServer* __pIpcServer;
	_MessagePortService* __pService;

}; // _MessagePortStub

//} } // Tizen::Io

#endif // _FIO_INTERNAL_MESSAGE_PORT_STUB_H_

